// Console de jeux avec Menu de selection pour l'ecran TFT2.2" de www.TechToys.com.hk
// Controlleur SSD1289 de Solomon
//
// 3D Cube demo , Casse Brique et Lunar Lander
//
// Utiliser le driver SSD1289.c
// A Changer dans SSD1289.c si les broches utilis sont differentes
// 
// #define  glcd_wr             PIN_C0
// #define  glcd_rd             PIN_C1
// #define  glcd_cs             PIN_C2
// #define  glcd_cd             PIN_C6
// Le port de donnes D1  D7 de l'cran est connect au PORT D (D0 -> D7) du PIC
//
// Modifier set_tris_C et D de la fonction LCD_Init si necessaire
//
// F. Muller 06 Juillet 2007
// Version 1.0b
//
// CCS C version : 4.032
// Pour PIC18F4680 32Mhz (Int_Osc 8Mhz , PLL x 4)
//
// Le Joystick digital sera compos de 3 bouttons connect sur les Pin :
// B1 : Droite
// B2 : Monte
// B3 : Gauche
//
// Le Joystick analogique (potentiometre) sera connect  la broche A0 ( integrer)

#include <SSD1289_18F4680_GameBoard.h>
#include <stdlib.h>
#include <string.h>
#include <SSD1289.c>
#include <trigotable.h>

// Variables Globales
// Lunar Lander            **********************************************************************
INT8U   PosX,OldPosX;                    //Position X du vaisseau
INT16U  PosY,OldPosY;                    //Position Y du vaisseau
INT8U   Plx;                             //Position X de la plateforme
INT16U  Ply;                             //Position Y de la plateforme
INT8U   Booster = 0;                     //1 = Afficher le booster
float   Vitesse = 0.1;                   //Vitesse de chute du Vaisseau

// Casse Brique            **********************************************************************
// Tableau de briques
INT8U Brique[13][10];                  // 10 lignes de 13 briques (ne pas utiliser int1 !!!)
// Position de la raquette
INT8U Raquette,OldRaq;                 // Position de depart de la raquette
INT8U RaqDroite;                       // Pixel droit de la raquette
INT8U TailleRaq = 40;                  // Taille de la raquette
// Position de la balle
INT8U  Ballex;                         // Position de la balle en X
INT16U Balley;                         // Position de la balle en Y
INT8U  OldBalleX;                      // Position de la balle sauvegard
INT16U OldBalleY;                      // Position de la balle sauvegard
// Direction de la Balle
signed int8 Dx,Dy;                     // Direction X et Y de la balle
// Coordonne de la brique Touch
INT8U    Touchex;
INT16U   Touchey;

// 3D Cube Demo            **********************************************************************
// Variables globales composant les points et les faces du Cube
const signed int px[8]={-10,10,10,-10,-10,10,10,-10};   // Les points X du cube
const signed int py[8]={-10,-10,10,10,-10,-10,10,10};   // Les points Y du cube
const signed int pz[8]={-10,-10,-10,-10,10,10,10,10};   // Les points Z du cube

const int face[12][3]={{0,1,2},{2,3,0},{1,5,6},{6,2,1},    // Les faces du cube
                       {5,4,7},{7,6,5},{4,0,3},{3,7,4},
                       {3,2,6},{6,7,3},{0,4,5},{5,1,0}};

// Commun
char    chiffre[5];                      //Pour Afficher un score (si necessaire)
INT8U   MenuSelected = 0;                //Jeux ou demo selectionn dans le menu
INT16U Score = 0;                      // ...


// Declaration des fonctions
// Lunar Lander
void Lander(void);                      //Le jeux en lui meme
void AfficheVaisseau();                 //Affichage du vaisseau
void TestPlateforme();                  //Test pour voir si le Vaisseau a atterri ou s'est crach
void AfficheEcran();                    //Affichage de la plateforme et terrain en dbut de patie

// Casse Brique
void KasBrick(void);
void AfficheBrique(void);
void TestBrique(void);
void testraquette(void);

// 3D Cube Demo
void Obj3D(void);

// Commun
void GameOverTxt(void);                 //On a perdu
void Gagne_Partie(void);                //On a gagn
void Menu(void);

void main()
{
   setup_adc_ports(AN0_TO_AN1|VSS_VDD);
   setup_adc(ADC_CLOCK_INTERNAL|ADC_TAD_MUL_0);
   setup_psp(PSP_DISABLED);
   setup_spi(FALSE);
   setup_wdt(WDT_OFF);
   setup_timer_0(RTCC_INTERNAL);                    
   setup_timer_2(T2_DISABLED,0,1);
   setup_timer_3(T3_DISABLED|T3_DIV_BY_1);
   setup_comparator(NC_NC_NC_NC);
   setup_vref(FALSE);
   //setup_oscillator(OSC_32MHZ);
   setup_timer_1(T1_INTERNAL | T1_DIV_BY_8); //1000 ticks a 32Mhz = 1Ms

   disable_interrupts(GLOBAL);

   //Configurer le Port B en entres pour joystick
   SET_TRIS_B(0xFF);
   port_b_pullups(TRUE);
   
   // Stabilisation de l'alimentation
   delay_ms(1000);
   
   // Toujour initialiser le LCD en 1er
   LCD_Init();

   // Effacer l'ecran en NOIR
   LCD_CLS(NOIR);
   LCD_CLS(BLEU);
   LCD_CLS(VERT);
   LCD_CLS(ROUGE);
   LCD_CLS(JAUNE);
   LCD_CLS(BLANC);
   LCD_CLS(MAUVE);
   LCD_CLS(ORANGE);
   LCD_CLS(NOIR);
   
   while(1)
   {
   // Lancer le Menu
   Menu();
   }
}

// Lunar Lander
// **********************************************************************************************

void Lander(void)
 {
   float   Vx = 0.0;                        //Vitesse horizontale du Vaisseau
   float   Carburant = 50.0;                //Carburant du vaisseau
   float   ForceG = 1.63;                   //La gravit (1.63 pour la Lune "9.8 / 6")
   INT16U  PiedD,PiedG;                     //Couleur presente sous les pied droite et gauche
   INT16U  Compteur1 = 0;                   //Compteur du Timer
   INT8U   Recalculer = 0;                  //1 = Recalculer les vitesse
   INT8U   Reafficher = 0;                  //1 = Reafficher le vaisseau
   INT8U   Droite = 0,Gauche = 0,Monte = 0; //Touche de direction
   
   //Position de la plateforme
   plx = (INT8U)(rand()%175)+20;
   ply = (rand()%50)+ 265;

   //Initialiser l'ecran
   AfficheEcran();
   
   //Position du Vaisseau en dbut de partie (25 est le minimum en Y)
   PosX = (INT8U)(rand()%175)+20;
   PosY = (rand()%50)+ 25;

   // Initialiser le Timer
   set_timer1(0);
   
   While(1)
    {
      if (get_timer1() > 10000)          //10mS
         {
            set_timer1(0);
            
            if ((++Compteur1 % 10) == 0) //100mS
               {
                  Recalculer = 1;
                  Reafficher = 1;
               }
               
            if (Compteur1 == 100)        //1 Sec
               {
                  Compteur1 = 0;         //Remettre le Compteur a 0
               }
         }
         
      //Test des bouttons
      if (!(input_b() & 4)) Monte  = 1;         //Activer le Booster
      if (!(input_b() & 2)) Droite = 1;         //Le vaisseau va vers la Droite
      if (!(input_b() & 8)) Gauche = 1;         //Le vaisseau va vers la Gauche
      
      // Cette routine est execut toutes les 100mS
      if (Recalculer == 1)
       {
         Vitesse += (ForceG * 0.1) ;     //(ForceG / 10) ,Force appliqu tout les 10eme de secondes
         //Ralentir le Vaisseau si le booster est activ
         if((Monte == 1) && (Carburant > 0))
          {
           Vitesse -= (ForceG * 0.15);  //Ralentir la descente si le Booster est activ
           Carburant -= 0.3;
           Monte = 0;
           Booster = 1;
          }
         if((Droite == 1) && (Carburant > 0))
          {
            Vx += 0.1;                  //Vitesse horizontale vers la droite
            Carburant -= 0.1;
            Droite =0;
          }
         if((Gauche == 1) && (Carburant > 0))
          {
            Vx -= 0.1;                  //Vitesse horizontale vers la gauche
            Carburant -= 0.1;
            Gauche =0;
          }
          // Enregistrer position du vaisseau
          OldPosX = PosX ; OldPosY = PosY;
          PosY += Vitesse;
          //On verifie que le vaisseau reste dans l'ecran
          if (PosY > 289) Posy = 289;
          if (PosY < 25)  PosY = 25;
          PosX += Vx;
          if (PosX > 215) PosX = 215;
          if (PosX < 5) PosX = 5;
          
          Recalculer = 0;
       }
      // Cette routine est execut toutes les 100mS
      if(Reafficher == 1)
      {
         sprintf(chiffre,"%f",Vitesse);
         LCD_Rect(0,6,60,21,YES,NOIR);
         if (Vitesse > 1.5)
            LCD_Text57(1,6,chiffre,2,ROUGE,NOIR);  //On descent trop vite
         else
            LCD_Text57(1,6,chiffre,2,VERT,NOIR);   //Bonne vitesse pour atterir
            
         sprintf(chiffre,"%f",Carburant);
         LCD_Rect(60,6,140,21,YES,NOIR);
         if (Carburant > 20)
            LCD_Text57(60,6,chiffre,2,VERT,NOIR);  //Carburant suffisant
         else
            LCD_Text57(60,6,chiffre,2,ROUGE,NOIR); //Plus ass de carburant
            
         //Afficher le Vaisseau
         AfficheVaisseau();
         // Tester si le vaisseau touche le terrain
         PiedD = LCD_Read_Pixel(PosX , PosY + 31);
         PiedG = LCD_Read_Pixel(PosX + 20, PosY + 31);
         Reafficher = 0;
      }
      
      // Tester si l'on est au dessus de la plateforme
      if (PosY > (Ply - 33))
         {
         if ((PosX >= Plx ) && (PosX <= (Plx + 20)))
            TestPlateforme();
         }
         
      if (LCD_Read_Pixel(PosX , PosY + 31) == BLEU)    //Pied Gauche du vaisseau sur terrain
         gameovertxt();
      if (LCD_Read_Pixel(PosX + 20, PosY + 31) == BLEU)//Pied droit  du vaisseau sur terrain
         gameovertxt();
    }
 }

// Afficher le Vaisseau
void AfficheVaisseau()
 { 
   //Effacer le Vaisseau de l'ancienne position
   LCD_Ligne(OldPosX + 10 , OldPosY , OldPosX + 20 , OldPosY + 20 , NOIR);
   LCD_Ligne(OldPosX + 20 , OldPosY + 20 , OldPosX + 20 , OldPosY + 30 , NOIR);
   LCD_Ligne(OldPosX + 20 , OldPosY + 30 , OldPosX + 17 , OldPosY + 20 , NOIR);
   LCD_Ligne(OldPosX + 17 , OldPosY + 20 , OldPosX + 3 , OldPosY + 20 , NOIR);
   LCD_Ligne(OldPosX + 3 , OldPosY + 20, OldPosX , OldPosY + 30 , NOIR);
   LCD_Ligne(OldPosX , OldPosY + 30 , OldPosX , OldPosY + 20 , NOIR);
   LCD_Ligne(OldPosX , OldPosY + 20 , OldPosX + 10 , OldPosY , NOIR);
   //Effacer le Booster
   LCD_Ligne(OldPosX + 6 , OldPosY + 21 , OldPosX + 13 , OldPosY + 21 , NOIR);
   LCD_Ligne(OldPosX + 13 , OldPosY + 21 , OldPosX + 10 , OldPosY + 30 , NOIR);
   LCD_Ligne(OldPosX + 10 , OldPosY + 30 , OldPosX + 6 , OldPosY + 21 , NOIR);
 
   //Le Vaisseau a la nouvelle Position
   LCD_Ligne(PosX + 10 , PosY , PosX + 20 , PosY + 20 , BLANC);
   LCD_Ligne(PosX + 20 , PosY + 20 , PosX + 20 , PosY + 30 , BLANC);
   LCD_Ligne(PosX + 20 , PosY + 30 , PosX + 17 , PosY + 20 , BLANC);
   LCD_Ligne(PosX + 17 , PosY + 20 , PosX + 3 , PosY + 20 , BLANC);
   LCD_Ligne(PosX + 3 , PosY + 20, PosX , PosY + 30 , BLANC);
   LCD_Ligne(PosX , PosY + 30 , PosX , PosY + 20 , BLANC);
   LCD_Ligne(PosX , PosY + 20 , PosX + 10 , PosY , BLANC);
   //Le Booster
   if (Booster == 1)
   {
      LCD_Ligne(PosX + 6 , PosY + 21 , PosX + 13 , PosY + 21 , ROUGE);
      LCD_Ligne(PosX + 13 , PosY + 21 , PosX + 10 , PosY + 30 , ROUGE);
      LCD_Ligne(PosX + 10 , PosY + 30 , PosX + 6 , PosY + 21 , ROUGE);
      Booster = 0;
   }
 }

// Tester si le Vaisseau se pose ou s'ecrase
void TestPlateforme()
 {
   if (Vitesse <= 1.5)
      Gagne_Partie();
   else
      gameovertxt();
 }

// Affichage de l'ecran en debut de jeux
void AfficheEcran()
 {
   INT8U Compteur;                                 //Compteur de bouvle
   INT16U py;                                      //Pour le terrain
   
   //Dessin de la plateforme
   LCD_Rect(Plx,ply,Plx+40,ply+5,YES,JAUNE);
   //Dessin du terrain a gauche de la plateforme
   py = ply + ((rand()%7)-3);
   for (Compteur = Plx-1;Compteur > 0;Compteur --)
      {  
         py = py + ((rand()%7)-3);
         LCD_Ligne(Compteur , py ,Compteur , 319 , BLEU);
      }
   //Dessin du terrain a droite de la plateforme
   py = ply + ((rand()%7)-3);
   for (Compteur = Plx + 41;Compteur < 240;Compteur ++)
      {
         py = py + ((rand()%7)-3);
         LCD_Ligne(Compteur , py ,Compteur , 319 , BLEU);
      }
   //Dessin du terrain sous la plateforme
   for (Compteur = Plx;Compteur < Plx + 41;Compteur ++)
      {
         LCD_Ligne(Compteur , ply+6 ,Compteur , 319 , BLEU);
      }
 }

// Casse Brique
//***********************************************************************************************
void KasBrick(void)
{
   INT16U   value1 = 0;

   // Afficher les Briques
   affichebrique();

   // Initialiser Position Raquette
   Raquette = 0;

   // Initialiser Position de la Balle
   Ballex = 119 ;
   Balley = 200 ;
   OldBallex = Ballex ;
   OldBalley = Balley ;

   Dx = 2;
   Dy = -2;
   // Routine de traitement
   do
     {
      // Lire la valeur ADC
      value1 = read_adc();
      OldRaq = Raquette;
      Raquette = (INT8U)(value1  * .234);
      // Tester sortie ecran de la raquette
      if (Raquette > (239 - TailleRaq)) Raquette = (239-TailleRaq);

      RaqDroite = Raquette + TailleRaq;
      // Effacer Ancienne Position de la Raquette si necessaire
      //       Et reafficher a la nouvelle Position
      if (Raquette != OldRaq)
       {
         LCD_Rect(OldRaq,316,OldRaq + 40,319,YES,NOIR);
         LCD_Rect(Raquette,316,RaqDroite,319,YES,BLEUCLAIR);
       }
      OldBalleX = Ballex ;
      OldBalleY = Balley ;
      BalleX += Dx;
      BalleY += Dy;
      // La balle sort du Haut de l'ecran ?
      if (Balley < 2) Dy = abs(Dy);
      // La Balle arrive a Hauteur de la raquette en Y ?
      // Faire un Test pour voir si Balle receptionne
      if (Balley >= 314) TestRaquette();
      // La balle touche le bord droit de l'ecran ?
      if (Ballex > 237) Dx = -Dx;
      // La balle touche le bord gauche de d'ecran ?
      if (Ballex < 2) Dx = abs(Dx);
      Touchey = (INT16U)(Balley / 12);
      LCD_Rect(OldBallex - 2,Oldballey - 2,Oldballex + 2,OldBalley + 2,YES,NOIR);
      LCD_Rect(Ballex - 2,balley - 2,ballex + 2,Balley + 2,YES,ROUGE);
      // La balle entre dans le Mur de brique ?
      if ((Touchey >= 0) && (Touchey <= 9))
         {
            Touchex = (INT8U)(Ballex / 18);
            if (Touchex <=12)
               // Tester si touche le mur de briques
               TestBrique();
         }

      Delay_ms(20);
     }
   while (TRUE);

}

// Afficher les Briques en Debut de partie
void affichebrique(void)
 {
   int8  x;
   int8  y;

   for (x=0;x<13;x++)
      for (y=0;y<10;y++)
         {
          LCD_Rect(x * 18, y * 12, (x*18)+16, (y*12)+10, YES, VERTCLAIR);
          Brique[x][y] = 1;
         }
 }

// Tester si la Balle Touche une brique
void TestBrique(void)
 {
     // S'il y a une Brique
     if (Brique[Touchex][Touchey] == 1)
        {
          Brique[Touchex][Touchey] = 0;
          // Effacer la brique
          LCD_Rect(Touchex * 18,Touchey * 12,(Touchex * 18) + 16,(Touchey * 12) + 10,YES,NOIR);
          // On augmente le score ...
          Score += 10;
          itoa(Score, 10, chiffre);
          LCD_Rect(0,260,62,282,YES,NOIR);
          LCD_Text57(0,260,chiffre,3,VERT,NOIR);
          // On as detruit tout le mur ?? (Score Max = 1300)
          if (Score >= 1300) Gagne_Partie();
          // Verifier Direction en Y de la Balle et l'inverser
          if (Dy > 0)
            Dy = -Dy;
          else
            Dy = abs(Dy);
        }
 }

// Test pour voir si la Balle est pass derriere la raquette
void testraquette(void)
 {
   // balle a Droite de la raquette ?
   if (ballex < raquette)
      gameovertxt();
   // balle a Gauche de la raquette ?
   if (ballex > RaqDroite)
      gameovertxt();
   // balle sur la raquette on inverse Direction Y
   Dy = -Dy;
   // Maintenant on test ou la balle se rouve sur la raquette
   // Sur la partie Gauche de la raquette (bord)
   if ((ballex >= raquette) && (ballex <= (unsigned char)(raqdroite/4)))
      // Si la Balle vient de la Gauche on inverse Dx
      if (Dx > 0)
        Dx = -3;
   // Sur la partie Gauche de la raquette (1/4 vers centre)
   if ((ballex >= (unsigned char)(raqdroite/4)) && (ballex <= (unsigned char)(raqdroite/2)))
      // Si la Balle vient de la Gauche on inverse Dx
      if (Dx > 0)
        Dx = -2;

   // Sur la partie Droite de la raquette bord)
   if ((ballex >= ((unsigned char)(raqdroite / 2)+(unsigned char)(raqdroite / 4))) && (ballex <= raqdroite))
      // Si la balle vient de la Droite on inverse Dx
      if (Dx < 0)
        Dx = 3;
    // Sur la partie Droite de la raquette (1/4 aprs milieu vers droite)
   if ((ballex >= (unsigned char)(raqdroite / 2)) && ((ballex <= raqdroite)-(unsigned char)(raqdroite / 4)))
      // Si la balle vient de la Droite on inverse Dx
      if (Dx < 0)
        Dx = 2;
}


// 3D Cube Demo
//***********************************************************************************************
void Obj3D(void)
  {
   // Calculer et tracer le cube
   float  tx,ty,tz,x,y,z;              // Coordonnes temporaires
   int i;                              // Compteur
   float sx,sy,sz,cx,cy,cz;            // Sin et Cos precalcul
   INT16U ax,ay,az;                    // Les angles de 0  359 degres
   INT8U dx,zoom;                      // Centrage x,y et zoom du cube
   INT16U dy;
   INT8U  nx[8];                       // Coordonnes de tracage
   INT16U ny[8];
   INT8U oldx[8];                      // Sauvegarde des ancienne coordonnes
   INT16U oldy[8];


   // Angles de dpart
   ax = 45;
   ay = 20;
   az = 0;

   // Zoom du cube
   zoom = 3;

   // Centrage du cube
   dx = 119;
   dy = 159;

   // Rotation du cube
   While(1)
   {

    // Tranfers des sin et cos prcalcul dans les variables de travail
    sx = si[ax]; sy = si[ay]; sz = si[az];
    cx = co[ax]; cy = co[ay]; cz = co[az];


    // Calculer les nouvelles coordonnes des points
    for (i=0; i<8; i++)
        {
           tx = px[i]; ty = py[i]; tz = pz[i];

           // Sauvegarde des anciennes coordonnes
           oldx[i] = nx[i]; oldy[i] = ny[i];

           // Rotation sur Axe X
           y = ty * cx - tz * sx;
           z = ty * sx + tz * cx;
           ty =y; tz = z;
           // Rotation en Z
           x = tx * cz - ty * sz;
           y = tx * sz + ty * cz;
           tx = x; ty = y;
           // Rotation en Y
           x = tx * cy - tz * sy;
           z = tx * sy + tz * cy;
           // Sauver les coordonnes ecran
           nx[i] = (INT8U)x * zoom + dx;
           ny[i] = (INT16U)y * zoom + dy;
        }
        delay_ms(5);

    // Effacer l'ancien cube et afficher le nouveau
    for (i=0; i<12; i++)
        { 
             LCD_Ligne(oldx[face[i][0]],oldy[face[i][0]],oldx[face[i][1]],oldy[face[i][1]], NOIR);
             LCD_Ligne(oldx[face[i][1]],oldy[face[i][1]],oldx[face[i][2]],oldy[face[i][2]], NOIR);
             LCD_Ligne(nx[face[i][0]],ny[face[i][0]],nx[face[i][1]],ny[face[i][1]], BLEU);
             LCD_Ligne(nx[face[i][1]],ny[face[i][1]],nx[face[i][2]],ny[face[i][2]], BLEU);
        }
    // Incrementer les angles
    ax = ax + 3; if (ax > 359) ax = ax - 360;
    ay = ay + 3; if (ay > 359) ay = ay - 360;
    az = az + 3; if (az > 359) az = az - 360;
   }
  }


// Commun
//**********************************************************************************************

// Fin du jeux et Reset du Pic
void gameovertxt(void)
 {
   char    gameover[] = "GAME OVER";        // Pas besoin d'explication ;)
   
   // La balle est pass derriere la raquette ...
   LCD_Rect(20,200,110,220,YES,NOIR);
   LCD_Text57(20,200,gameover,2,BLEUCLAIR,NOIR);
   delay_ms(2000);
   // Effacer ecran
   LCD_CLS(NOIR);
   delay_ms(25);
   reset_cpu();
 }

// On a reussi , message + reset du Pic
void Gagne_Partie(void)
 {
   char    Gagne[] = "Reussi !!";       // Pas besoin d'explication ;)
   
   // La partie est gagne
   LCD_Rect(20,200,131,220,YES,NOIR);
   LCD_Text57(20,200,Gagne,2,BLEUCLAIR,NOIR);
   delay_ms(2000);
   // Effacer ecran
   LCD_CLS(NOIR);
   delay_ms(25);
   reset_cpu();
 }


// Menu principal *******************************************************************************
// Selection du jeux ou demo a lancer
void Menu(void)
{
   INT8U MaxMenu = 3;
   INT8U OldSelected;
   
   char    menu1[] = "3D Cube Demo";
   char    menu2[] = "Casse Brique";
   char    menu3[] = "Lunar Lander";

   MenuSelected = 0;
   OldSelected  = 0;
   // Effacer ecran
   LCD_CLS(NOIR);
   
   //La navigation se fait au joystick
   //Touche Haut   = surligner une entre du menu
   //Touche Droite = selectionner et lancer l'entre surlign
   //while(1)
      {
         //Test des bouttons
         if (!(input_b() & 4)) MenuSelected  -= 1;
         if (MenuSelected < 1)
               MenuSelected = MaxMenu;
         if (MenuSelected != OldSelected)
            {
               OldSelected = MenuSelected;
               
               switch (MenuSelected)
                  {
                     case 1:
                        {
                           LCD_Text57(20,100,menu1,3,VERTCLAIR,NOIR);
                           LCD_Text57(20,130,menu2,3,ROUGE,NOIR);
                           LCD_Text57(20,160,menu3,3,ROUGE,NOIR);
                           break;
                        }
                     case 2:
                        {
                           LCD_Text57(20,100,menu1,3,ROUGE,NOIR);
                           LCD_Text57(20,130,menu2,3,VERTCLAIR,NOIR);
                           LCD_Text57(20,160,menu3,3,ROUGE,NOIR);
                           break;
                        }
                     case 3:
                        {
                           LCD_Text57(20,100,menu1,3,ROUGE,NOIR);
                           LCD_Text57(20,130,menu2,3,ROUGE,NOIR);
                           LCD_Text57(20,160,menu3,3,VERTCLAIR,NOIR);
                           break;
                        }
                  }
            }
         Delay_ms(200);
         
         if (!(input_b() & 2))                  //On a valid une selection
            {
               switch (MenuSelected)
                  {
                     case 1:
                        {
                           // On lance 3D Cube demo
                           // Effacer ecran
                           LCD_CLS(NOIR);
                           Obj3D();
                           break;
                        }
                     case 2:
                        {
                           // On lance le jeux Casse Brique
                           // Effacer ecran
                           LCD_CLS(NOIR);
                           KasBrick();
                           break;
                        }
                     case 3:
                        {
                           // On lance le jeux Lunar Lander
                           // Effacer ecran
                           LCD_CLS(NOIR);                           
                           Lander();
                           break;
                        }
                  }
            }
      }
}
